""" version which can be consumed from within the module """
VERSION_STR = "0.0.45"
DESCRIPTION = "Help you deal with multiple git repositories"
APP_NAME = "pymultigit"
LOGGER_NAME = "pymultigit"
